@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875a.  */
+/* A Bison parser, made by GNU Bison 1.875d.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -145,7 +145,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 30 "ASN1.y"
+#line 31 "ASN1.y"
 
 #include <int.h>
 #include <errors.h>
@@ -187,7 +187,7 @@ int _asn1_yylex(void);
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 60 "ASN1.y"
+#line 61 "ASN1.y"
 typedef union YYSTYPE {
   unsigned int constant;
   char str[MAX_NAME_SIZE+1];
@@ -210,18 +210,25 @@ typedef union YYSTYPE {
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
+# ifndef YYFREE
+#  define YYFREE free
+# endif
+# ifndef YYMALLOC
+#  define YYMALLOC malloc
+# endif
+
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
 # else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
-#   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
-#    endif
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   endif
 #  endif
 # endif
@@ -234,20 +241,20 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short yyss;
+  short int yyss;
   YYSTYPE yyvs;
   };
 
@@ -257,13 +264,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -299,7 +306,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short yysigned_char;
+   typedef short int yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -361,7 +368,7 @@ static const unsigned char yytranslate[] =
 #if YYDEBUG
 /* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
    YYRHS.  */
-static const unsigned short yyprhs[] =
+static const unsigned short int yyprhs[] =
 {
        0,     0,     3,    12,    14,    17,    20,    22,    24,    26,
       28,    30,    32,    36,    41,    43,    47,    49,    54,    56,
@@ -414,18 +421,18 @@ static const yysigned_char yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short yyrline[] =
+static const unsigned short int yyrline[] =
 {
-       0,   122,   122,   135,   136,   139,   143,   144,   147,   148,
-     151,   152,   155,   157,   162,   163,   167,   169,   174,   175,
-     179,   180,   181,   184,   186,   190,   191,   192,   195,   197,
-     198,   202,   203,   207,   208,   210,   211,   218,   221,   222,
-     225,   227,   233,   234,   237,   238,   242,   243,   247,   252,
-     253,   257,   258,   263,   269,   272,   274,   277,   278,   279,
-     280,   281,   282,   283,   284,   285,   286,   287,   288,   289,
-     292,   293,   298,   299,   302,   305,   308,   309,   313,   315,
-     317,   322,   324,   326,   331,   335,   336,   341,   344,   348,
-     353,   359,   360,   363,   364,   368,   371,   395,   396
+       0,   123,   123,   136,   137,   140,   144,   145,   148,   149,
+     152,   153,   156,   158,   163,   164,   168,   170,   175,   176,
+     180,   181,   182,   185,   187,   191,   192,   193,   196,   198,
+     199,   203,   204,   208,   209,   211,   212,   219,   222,   223,
+     226,   228,   234,   235,   238,   239,   243,   244,   248,   253,
+     254,   258,   259,   264,   270,   273,   275,   278,   279,   280,
+     281,   282,   283,   284,   285,   286,   287,   288,   289,   290,
+     293,   294,   299,   300,   303,   306,   309,   310,   314,   316,
+     318,   323,   325,   327,   332,   336,   337,   342,   345,   349,
+     354,   360,   361,   364,   365,   369,   372,   396,   397
 };
 #endif
 
@@ -434,31 +441,32 @@ static const unsigned short yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "\"::=\"", "NUM", "IDENTIFIER", "OPTIONAL", 
-  "INTEGER", "SIZE", "OCTET", "STRING", "SEQUENCE", "BIT", "UNIVERSAL", 
-  "PRIVATE", "APPLICATION", "DEFAULT", "CHOICE", "OF", "OBJECT", 
-  "STR_IDENTIFIER", "BOOLEAN", "TRUE", "FALSE", "TOKEN_NULL", "ANY", 
-  "DEFINED", "BY", "SET", "EXPLICIT", "IMPLICIT", "DEFINITIONS", "TAGS", 
-  "BEGIN", "END", "UTCTime", "GeneralizedTime", "GeneralString", "FROM", 
-  "IMPORTS", "ENUMERATED", "'+'", "'-'", "'('", "')'", "','", "'['", 
-  "']'", "'|'", "'{'", "'}'", "'.'", "$accept", "definitions", "pos_num", 
-  "neg_num", "pos_neg_num", "num_identifier", "pos_neg_identifier", 
-  "constant", "constant_list", "obj_constant", "obj_constant_list", 
-  "class", "tag_type", "tag", "default", "pos_neg_list", "integer_def", 
-  "boolean_def", "Time", "size_def2", "size_def", "generalstring_def", 
-  "octet_string_def", "bit_element", "bit_element_list", "bit_string_def", 
-  "enumerated_def", "object_def", "type_assig_right", 
-  "type_assig_right_tag", "type_assig_right_tag_default", "type_assig", 
-  "type_assig_list", "sequence_def", "set_def", "choise_def", "any_def", 
-  "type_def", "constant_def", "type_constant", "type_constant_list", 
-  "definitions_id", "explicit_implicit", 0
+  "$end", "error", "$undefined", "\"::=\"", "NUM", "IDENTIFIER",
+  "OPTIONAL", "INTEGER", "SIZE", "OCTET", "STRING", "SEQUENCE", "BIT",
+  "UNIVERSAL", "PRIVATE", "APPLICATION", "DEFAULT", "CHOICE", "OF",
+  "OBJECT", "STR_IDENTIFIER", "BOOLEAN", "TRUE", "FALSE", "TOKEN_NULL",
+  "ANY", "DEFINED", "BY", "SET", "EXPLICIT", "IMPLICIT", "DEFINITIONS",
+  "TAGS", "BEGIN", "END", "UTCTime", "GeneralizedTime", "GeneralString",
+  "FROM", "IMPORTS", "ENUMERATED", "'+'", "'-'", "'('", "')'", "','",
+  "'['", "']'", "'|'", "'{'", "'}'", "'.'", "$accept", "definitions",
+  "pos_num", "neg_num", "pos_neg_num", "num_identifier",
+  "pos_neg_identifier", "constant", "constant_list", "obj_constant",
+  "obj_constant_list", "class", "tag_type", "tag", "default",
+  "pos_neg_list", "integer_def", "boolean_def", "Time", "size_def2",
+  "size_def", "generalstring_def", "octet_string_def", "bit_element",
+  "bit_element_list", "bit_string_def", "enumerated_def", "object_def",
+  "type_assig_right", "type_assig_right_tag",
+  "type_assig_right_tag_default", "type_assig", "type_assig_list",
+  "sequence_def", "set_def", "choise_def", "any_def", "type_def",
+  "constant_def", "type_constant", "type_constant_list", "definitions_id",
+  "explicit_implicit", 0
 };
 #endif
 
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short yytoknum[] =
+static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -526,7 +534,7 @@ static const unsigned char yydefact[] =
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
-static const short yydefgoto[] =
+static const short int yydefgoto[] =
 {
       -1,     2,   101,   102,   103,    10,   184,   114,   115,    11,
       12,    93,    51,    52,   171,   111,    53,    54,    55,    72,
@@ -538,7 +546,7 @@ static const short yydefgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -84
-static const short yypact[] =
+static const short int yypact[] =
 {
       18,   -32,    33,    15,     0,   -84,    90,   -84,    49,   -84,
      -84,   -84,     2,   -84,   -84,    11,    45,   -84,   -84,    57,
@@ -562,7 +570,7 @@ static const short yypact[] =
 };
 
 /* YYPGOTO[NTERM-NUM].  */
-static const short yypgoto[] =
+static const short int yypgoto[] =
 {
      -84,   -84,   -84,   -84,   -72,   -73,   -84,    34,   -84,   -12,
      -83,   -84,   -84,   -84,   -84,   -84,   -84,   -84,   -84,   112,
@@ -576,7 +584,7 @@ static const short yypgoto[] =
    number is the opposite.  If zero, do what YYDEFACT says.
    If YYTABLE_NINF, syntax error.  */
 #define YYTABLE_NINF -9
-static const short yytable[] =
+static const short int yytable[] =
 {
       18,   110,   109,    96,     7,     8,     7,     8,     7,     8,
        7,     8,    74,    70,   133,    24,    70,     4,    75,   169,
@@ -599,7 +607,7 @@ static const short yytable[] =
      187,   188,   177,   106,   146,   172,   151,     0,     0,    34
 };
 
-static const short yycheck[] =
+static const short int yycheck[] =
 {
       12,    74,    74,    52,     4,     5,     4,     5,     4,     5,
        4,     5,    43,     8,    97,     5,     8,    49,    49,     6,
@@ -670,7 +678,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrlab1
+#define YYERROR		goto yyerrorlab
 
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
@@ -705,11 +713,11 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
@@ -753,17 +761,17 @@ do {								\
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short *bottom, short *top)
+yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -793,9 +801,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylineno = yyrline[yyrule];
+  unsigned int yylno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylineno);
+             yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -832,7 +840,7 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
 # undef YYMAXDEPTH
 #endif
 
@@ -1030,9 +1038,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	yyssa[YYINITDEPTH];
-  short *yyss = yyssa;
-  register short *yyssp;
+  short int yyssa[YYINITDEPTH];
+  short int *yyss = yyssa;
+  register short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1069,6 +1077,7 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1094,7 +1103,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1122,7 +1131,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1255,7 +1264,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 125 "ASN1.y"
+#line 126 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_DEFINITIONS|yyvsp[-5].constant);
                     _asn1_set_name(yyval.node,_asn1_get_name(yyvsp[-7].node));
                     _asn1_set_name(yyvsp[-7].node,"");
@@ -1267,175 +1276,175 @@ yyreduce:
     break;
 
   case 3:
-#line 135 "ASN1.y"
-    {strcpy(yyval.str,yyvsp[0].str);}
-    break;
-
-  case 4:
 #line 136 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
+  case 4:
+#line 137 "ASN1.y"
+    {strcpy(yyval.str,yyvsp[0].str);}
+    break;
+
   case 5:
-#line 139 "ASN1.y"
+#line 140 "ASN1.y"
     {strcpy(yyval.str,"-");
                        strcat(yyval.str,yyvsp[0].str);}
     break;
 
   case 6:
-#line 143 "ASN1.y"
-    {strcpy(yyval.str,yyvsp[0].str);}
-    break;
-
-  case 7:
 #line 144 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
-  case 8:
-#line 147 "ASN1.y"
+  case 7:
+#line 145 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
-  case 9:
+  case 8:
 #line 148 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
-  case 10:
-#line 151 "ASN1.y"
+  case 9:
+#line 149 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
-  case 11:
+  case 10:
 #line 152 "ASN1.y"
     {strcpy(yyval.str,yyvsp[0].str);}
     break;
 
+  case 11:
+#line 153 "ASN1.y"
+    {strcpy(yyval.str,yyvsp[0].str);}
+    break;
+
   case 12:
-#line 155 "ASN1.y"
+#line 156 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CONSTANT);
                                        _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 13:
-#line 157 "ASN1.y"
+#line 158 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CONSTANT);
 	                               _asn1_set_name(yyval.node,yyvsp[-3].str);
                                        _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 14:
-#line 162 "ASN1.y"
+#line 163 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 15:
-#line 163 "ASN1.y"
+#line 164 "ASN1.y"
     {yyval.node=yyvsp[-2].node;
                                             _asn1_set_right(_asn1_get_last_right(yyvsp[-2].node),yyvsp[0].node);}
     break;
 
   case 16:
-#line 167 "ASN1.y"
+#line 168 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CONSTANT);
                                    _asn1_set_value(yyval.node,yyvsp[0].str,strlen(yyvsp[0].str)+1);}
     break;
 
   case 17:
-#line 169 "ASN1.y"
+#line 170 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CONSTANT);
 	                            _asn1_set_name(yyval.node,yyvsp[-3].str);
                                     _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 18:
-#line 174 "ASN1.y"
+#line 175 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 19:
-#line 175 "ASN1.y"
+#line 176 "ASN1.y"
     {yyval.node=yyvsp[-1].node;
                                                     _asn1_set_right(_asn1_get_last_right(yyvsp[-1].node),yyvsp[0].node);}
     break;
 
   case 20:
-#line 179 "ASN1.y"
+#line 180 "ASN1.y"
     {yyval.constant=CONST_UNIVERSAL;}
     break;
 
   case 21:
-#line 180 "ASN1.y"
+#line 181 "ASN1.y"
     {yyval.constant=CONST_PRIVATE;}
     break;
 
   case 22:
-#line 181 "ASN1.y"
+#line 182 "ASN1.y"
     {yyval.constant=CONST_APPLICATION;}
     break;
 
   case 23:
-#line 184 "ASN1.y"
+#line 185 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_TAG);
                             _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 24:
-#line 186 "ASN1.y"
+#line 187 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_TAG | yyvsp[-2].constant);
                                 _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 25:
-#line 190 "ASN1.y"
+#line 191 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 26:
-#line 191 "ASN1.y"
+#line 192 "ASN1.y"
     {yyval.node=_asn1_mod_type(yyvsp[-1].node,CONST_EXPLICIT);}
     break;
 
   case 27:
-#line 192 "ASN1.y"
+#line 193 "ASN1.y"
     {yyval.node=_asn1_mod_type(yyvsp[-1].node,CONST_IMPLICIT);}
     break;
 
   case 28:
-#line 195 "ASN1.y"
+#line 196 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_DEFAULT);
                                        _asn1_set_value(yyval.node,yyvsp[0].str,strlen(yyvsp[0].str)+1);}
     break;
 
   case 29:
-#line 197 "ASN1.y"
+#line 198 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_DEFAULT|CONST_TRUE);}
     break;
 
   case 30:
-#line 198 "ASN1.y"
+#line 199 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_DEFAULT|CONST_FALSE);}
     break;
 
   case 33:
-#line 207 "ASN1.y"
+#line 208 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_INTEGER);}
     break;
 
   case 34:
-#line 208 "ASN1.y"
+#line 209 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_INTEGER|CONST_LIST);
 	                                 _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 35:
-#line 210 "ASN1.y"
+#line 211 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_INTEGER);}
     break;
 
   case 36:
-#line 212 "ASN1.y"
+#line 213 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_INTEGER|CONST_MIN_MAX);
                                          _asn1_set_down(yyval.node,_asn1_add_node(TYPE_SIZE));
                                          _asn1_set_value(_asn1_get_down(yyval.node),yyvsp[-1].str,strlen(yyvsp[-1].str)+1);
@@ -1443,293 +1452,293 @@ yyreduce:
     break;
 
   case 37:
-#line 218 "ASN1.y"
+#line 219 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_BOOLEAN);}
     break;
 
   case 38:
-#line 221 "ASN1.y"
+#line 222 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_TIME|CONST_UTC);}
     break;
 
   case 39:
-#line 222 "ASN1.y"
+#line 223 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_TIME|CONST_GENERALIZED);}
     break;
 
   case 40:
-#line 225 "ASN1.y"
+#line 226 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SIZE|CONST_1_PARAM);
 	                              _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 41:
-#line 228 "ASN1.y"
+#line 229 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SIZE|CONST_MIN_MAX);
 	                              _asn1_set_value(yyval.node,yyvsp[-4].str,strlen(yyvsp[-4].str)+1);
                                       _asn1_set_name(yyval.node,yyvsp[-1].str);}
     break;
 
   case 42:
-#line 233 "ASN1.y"
+#line 234 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 43:
-#line 234 "ASN1.y"
+#line 235 "ASN1.y"
     {yyval.node=yyvsp[-1].node;}
     break;
 
   case 44:
-#line 237 "ASN1.y"
+#line 238 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_GENERALSTRING);}
     break;
 
   case 45:
-#line 238 "ASN1.y"
+#line 239 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_GENERALSTRING|CONST_SIZE);
 	                            	  _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 46:
-#line 242 "ASN1.y"
+#line 243 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OCTET_STRING);}
     break;
 
   case 47:
-#line 243 "ASN1.y"
+#line 244 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OCTET_STRING|CONST_SIZE);
                                            _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 48:
-#line 247 "ASN1.y"
+#line 248 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CONSTANT);
 	                           _asn1_set_name(yyval.node,yyvsp[-3].str);
                                     _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);}
     break;
 
   case 49:
-#line 252 "ASN1.y"
+#line 253 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 50:
-#line 253 "ASN1.y"
+#line 254 "ASN1.y"
     {yyval.node=yyvsp[-2].node;
                                                        _asn1_set_right(_asn1_get_last_right(yyvsp[-2].node),yyvsp[0].node);}
     break;
 
   case 51:
-#line 257 "ASN1.y"
+#line 258 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_BIT_STRING);}
     break;
 
   case 52:
-#line 259 "ASN1.y"
+#line 260 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_BIT_STRING|CONST_LIST);
                                 _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 53:
-#line 264 "ASN1.y"
+#line 265 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_ENUMERATED|CONST_LIST);
                                 _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 54:
-#line 269 "ASN1.y"
+#line 270 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OBJECT_ID);}
     break;
 
   case 55:
-#line 272 "ASN1.y"
+#line 273 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_IDENTIFIER);
                                        _asn1_set_value(yyval.node,yyvsp[0].str,strlen(yyvsp[0].str)+1);}
     break;
 
   case 56:
-#line 274 "ASN1.y"
+#line 275 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_IDENTIFIER|CONST_SIZE);
                                        _asn1_set_value(yyval.node,yyvsp[-1].str,strlen(yyvsp[-1].str)+1);
                                        _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 57:
-#line 277 "ASN1.y"
-    {yyval.node=yyvsp[0].node;}
-    break;
-
-  case 58:
 #line 278 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 59:
+  case 58:
 #line 279 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 61:
-#line 281 "ASN1.y"
+  case 59:
+#line 280 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 62:
+  case 61:
 #line 282 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 63:
+  case 62:
 #line 283 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 64:
+  case 63:
 #line 284 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 65:
+  case 64:
 #line 285 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 66:
+  case 65:
 #line 286 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 67:
+  case 66:
 #line 287 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 68:
+  case 67:
 #line 288 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
-  case 69:
+  case 68:
 #line 289 "ASN1.y"
+    {yyval.node=yyvsp[0].node;}
+    break;
+
+  case 69:
+#line 290 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_NULL);}
     break;
 
   case 70:
-#line 292 "ASN1.y"
+#line 293 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 71:
-#line 293 "ASN1.y"
+#line 294 "ASN1.y"
     {yyval.node=_asn1_mod_type(yyvsp[0].node,CONST_TAG);
                                                _asn1_set_right(yyvsp[-1].node,_asn1_get_down(yyval.node));
                                                _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 72:
-#line 298 "ASN1.y"
+#line 299 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 73:
-#line 299 "ASN1.y"
+#line 300 "ASN1.y"
     {yyval.node=_asn1_mod_type(yyvsp[-1].node,CONST_DEFAULT);
                                                        _asn1_set_right(yyvsp[0].node,_asn1_get_down(yyval.node));
 						       _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 74:
-#line 302 "ASN1.y"
+#line 303 "ASN1.y"
     {yyval.node=_asn1_mod_type(yyvsp[-1].node,CONST_OPTION);}
     break;
 
   case 75:
-#line 305 "ASN1.y"
+#line 306 "ASN1.y"
     {yyval.node=_asn1_set_name(yyvsp[0].node,yyvsp[-1].str);}
     break;
 
   case 76:
-#line 308 "ASN1.y"
+#line 309 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 77:
-#line 309 "ASN1.y"
+#line 310 "ASN1.y"
     {yyval.node=yyvsp[-2].node;
                                                 _asn1_set_right(_asn1_get_last_right(yyvsp[-2].node),yyvsp[0].node);}
     break;
 
   case 78:
-#line 313 "ASN1.y"
+#line 314 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SEQUENCE);
                                               _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 79:
-#line 315 "ASN1.y"
+#line 316 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SEQUENCE_OF);
                                               _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 80:
-#line 317 "ASN1.y"
+#line 318 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SEQUENCE_OF|CONST_SIZE);
                                             _asn1_set_right(yyvsp[-2].node,yyvsp[0].node);
                                             _asn1_set_down(yyval.node,yyvsp[-2].node);}
     break;
 
   case 81:
-#line 322 "ASN1.y"
+#line 323 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SET);
                                      _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 82:
-#line 324 "ASN1.y"
+#line 325 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SET_OF);
                                      _asn1_set_down(yyval.node,yyvsp[0].node);}
     break;
 
   case 83:
-#line 326 "ASN1.y"
+#line 327 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_SET_OF|CONST_SIZE);
                                        _asn1_set_right(yyvsp[-2].node,yyvsp[0].node);
                                        _asn1_set_down(yyval.node,yyvsp[-2].node);}
     break;
 
   case 84:
-#line 331 "ASN1.y"
+#line 332 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_CHOICE);
                                              _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 85:
-#line 335 "ASN1.y"
+#line 336 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_ANY);}
     break;
 
   case 86:
-#line 336 "ASN1.y"
+#line 337 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_ANY|CONST_DEFINED_BY);
                                         _asn1_set_down(yyval.node,_asn1_add_node(TYPE_CONSTANT));
 	                                _asn1_set_name(_asn1_get_down(yyval.node),yyvsp[0].str);}
     break;
 
   case 87:
-#line 341 "ASN1.y"
+#line 342 "ASN1.y"
     {yyval.node=_asn1_set_name(yyvsp[0].node,yyvsp[-2].str);}
     break;
 
   case 88:
-#line 345 "ASN1.y"
+#line 346 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OBJECT_ID|CONST_ASSIGN);
                          _asn1_set_name(yyval.node,yyvsp[-6].str);
                          _asn1_set_down(yyval.node,yyvsp[-1].node);}
     break;
 
   case 89:
-#line 349 "ASN1.y"
+#line 350 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OBJECT_ID|CONST_ASSIGN|CONST_1_PARAM);
                          _asn1_set_name(yyval.node,yyvsp[-5].str);
                          _asn1_set_value(yyval.node,yyvsp[-4].str,strlen(yyvsp[-4].str)+1);
@@ -1737,61 +1746,61 @@ yyreduce:
     break;
 
   case 90:
-#line 354 "ASN1.y"
+#line 355 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_INTEGER|CONST_ASSIGN);
                          _asn1_set_name(yyval.node,yyvsp[-3].str);
                          _asn1_set_value(yyval.node,yyvsp[0].str,strlen(yyvsp[0].str)+1);}
     break;
 
   case 91:
-#line 359 "ASN1.y"
-    {yyval.node=yyvsp[0].node;}
-    break;
-
-  case 92:
 #line 360 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
+  case 92:
+#line 361 "ASN1.y"
+    {yyval.node=yyvsp[0].node;}
+    break;
+
   case 93:
-#line 363 "ASN1.y"
+#line 364 "ASN1.y"
     {yyval.node=yyvsp[0].node;}
     break;
 
   case 94:
-#line 364 "ASN1.y"
+#line 365 "ASN1.y"
     {yyval.node=yyvsp[-1].node;
                                                           _asn1_set_right(_asn1_get_last_right(yyvsp[-1].node),yyvsp[0].node);}
     break;
 
   case 95:
-#line 368 "ASN1.y"
+#line 369 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OBJECT_ID);
                                                           _asn1_set_down(yyval.node,yyvsp[-1].node);
                                                           _asn1_set_name(yyval.node,yyvsp[-3].str);}
     break;
 
   case 96:
-#line 371 "ASN1.y"
+#line 372 "ASN1.y"
     {yyval.node=_asn1_add_node(TYPE_OBJECT_ID);
                                                           _asn1_set_name(yyval.node,yyvsp[-2].str);}
     break;
 
   case 97:
-#line 395 "ASN1.y"
+#line 396 "ASN1.y"
     {yyval.constant=CONST_EXPLICIT;}
     break;
 
   case 98:
-#line 396 "ASN1.y"
+#line 397 "ASN1.y"
     {yyval.constant=CONST_IMPLICIT;}
     break;
 
 
     }
 
-/* Line 999 of yacc.c.  */
-#line 1795 "ASN1.c"
+/* Line 1010 of yacc.c.  */
+#line 1804 "ASN1.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1832,18 +1841,33 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
-	  yysize += yystrlen ("syntax error, unexpected ") + 1;
-	  yysize += yystrlen (yytname[yytype]);
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -1852,16 +1876,13 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = yystpcpy (yyp, yyq);
+			yyp = yystpcpy (yyp, yyprefix);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyprefix = " or ";
 		      }
 		}
 	      yyerror (yymsg);
@@ -1882,25 +1903,27 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (yychar == YYEOF)
+      if (yychar <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (yyss < yyssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-	      yydestruct (yystos[*yyssp], yyvsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+          /* If at end of input, pop the error token,
+	     then the rest of the stack, then return failure.  */
+	  if (yychar == YYEOF)
+	     for (;;)
+	       {
+		 YYPOPSTACK;
+		 if (yyssp == yyss)
+		   YYABORT;
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp);
+	       }
         }
+      else
+	{
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval);
+	  yychar = YYEMPTY;
 
-      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-      yydestruct (yytoken, &yylval);
-      yychar = YYEMPTY;
-
+	}
     }
 
   /* Else will try to reuse lookahead token after shifting the error
@@ -1908,9 +1931,27 @@ yyerrlab:
   goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| yyerrorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+yyerrorlab:
+
+#ifdef __GNUC__
+  /* Pacify GCC when the user code never invokes YYERROR and the label
+     yyerrorlab therefore never appears in user code.  */
+  if (0)
+     goto yyerrorlab;
+#endif
+
+  yyvsp -= yylen;
+  yyssp -= yylen;
+  yystate = *yyssp;
+  goto yyerrlab1;
+
+
+/*-------------------------------------------------------------.
+| yyerrlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
@@ -1934,9 +1975,8 @@ yyerrlab1:
 
       YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
       yydestruct (yystos[yystate], yyvsp);
-      yyvsp--;
-      yystate = *--yyssp;
-
+      YYPOPSTACK;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
@@ -1985,7 +2025,7 @@ yyreturn:
 }
 
 
-#line 400 "ASN1.y"
+#line 401 "ASN1.y"
 
 
 
