@@ -1,43 +1,30 @@
 /*
- *      Copyright (C) 2000,2001,2002 Nikos Mavroyanopoulos
+ *      Copyright (C) 2000,2001,2002,2005 Nikos Mavroyanopoulos
  *
- * This file is part of LIBASN1.
+ * This file is part of LIBTASN1.
  *
- * LIBASN1 is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * LIBTASN1 is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * LIBASN1 is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * LIBTASN1 is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with LIBTASN1; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef DEFINES_H
 # define DEFINES_H
 
-#include <config.h>
-
-#ifndef __GNUC__
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else
-#  ifdef _AIX
-#pragma alloca
-#  else
-#   ifndef alloca	/* predefined by HP cc +Olibcalls */
-char *alloca();
-#   endif
-#  endif
-# endif
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 
-
 #ifdef STDC_HEADERS
 # include <string.h>
 # include <stdlib.h>
